#%% begin initialize phpPgAdmin-5.0.2-noname-P1
###################################################################
export LANG=C

if [ -r /tmp/SeTT_PX ]; then
  ROOT="`cat /tmp/SeTT_PX`"
fi

APACI_DIR=$ROOT/opt/httpd
PHP_DIR=$ROOT/opt/php5

( cd $ROOT/opt/htdocs;
  rm -f phpPgAdmin;
  ln -sf  phpPgAdmin-5.0.2  phpPgAdmin;
  /bin/su postgres -c 'psql -f phpPgAdmin/sql/reports-pgsql.sql';
)

sed -e 's%usr/bin%opt/pgsql/bin%' \
    $ROOT/opt/htdocs/phpPgAdmin/conf/config.inc.php-dist \
    > $ROOT/opt/htdocs/phpPgAdmin/conf/config.inc.php

/bin/chown -R wadm:apache $ROOT/opt/htdocs/phpPgAdmin-5.0.2

#/bin/su postgres -c '/opt/pgsql/bin/pg_passwd.sh www';
#%% end
